@@ -17,7 +17,7 @@ sub calculate {
 
 sub accumulator { [ 0, 0 ] }
 
-sub result {
+sub result_from {
   my ($self,  $accum) = @_;
   my ($count, $sum)   = @{$accum};
   return [ 0, 'e#DIV/0!' ] unless $count;
