@@ -1,6 +1,7 @@
 package Spreadsheet::Engine::Function::LEN;
 
 use strict;
+use warnings;
 
 use base 'Spreadsheet::Engine::Function::text';
 
@@ -8,7 +9,7 @@ sub arguments { [1] }
 
 sub calculate {
   my ($self, $string) = @_;
-  return length $string;
+  return length($string || '');
 }
 
 sub result_type { 'n' }
@@ -56,7 +57,7 @@ All Rights Reserved.
 
 Portions (c) Copyright 2007 Tony Bowden
 
-=head1 LICENSE
+=head1 LICENCE
 
 The contents of this file are subject to the Artistic License 2.0;
 you may not use this file except in compliance with the License.
