@@ -5,7 +5,7 @@ use warnings;
 
 use base 'Spreadsheet::Engine::Function::VAR';
 
-sub result {
+sub result_from {
   my ($self, $A) = @_;
   return [ 0, 'e#DIV/0!' ] unless $A->{count} > 1;
   return $A->{sk} / $A->{count};
